<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset='utf-8'>
    <meta name='viewport' content='width=device-width,initial-scale=1'>

    <title>Svelte app</title>

    <link rel='icon' type='image/png' href='/favicon.png'>
    <link rel='stylesheet' href='/static/svelte/global.css'>
    <link rel='stylesheet' href='/static/svelte/##svelte-app##/style.css'>
    <script>
        function getJinjaData() {
            const jinja_data = {{ data | tojson }}
            document.data = {
                ...jinja_data,
            }
        }
        getJinjaData();
    </script>

    <script defer src='/static/svelte/##svelte-app##/index.js'></script>
</head>

<body>
</body>

</html>