/** @type {import('tailwindcss').Config} */
export default {
  content: [
    "./app/svelte/**/*.svelte",
    "./app/svelte/**/*.js",
    "./app/templates/**/*.html",
  ],
  theme: {
    extend: {},
  },
  plugins: [],
}

